@@ -15,8 +15,8 @@ class DockerBaselineImageBuilder:
             enabled=True,
             vendor="Debian",
             distributions=[
-                #"stretch",
-                #"buster",
+                "stretch",
+                "buster",
                 # "bullseye",
             ],
             architectures=[
