@@ -68,7 +68,7 @@ def test_mqtt_to_grafana(machinery_hiveeyes, create_influxdb_hiveeyes, reset_inf
 
     logger.info('Grafana: Checking dashboards')
     for dashboard_name in settings.grafana_dashboards:
-        dashboard = grafana.client.dashboards.db[dashboard_name].get()['dashboard']
+        dashboard = grafana.get_dashboard_by_name(dashboard_name)['dashboard']
         if 'rows' in dashboard:
             umbrella = dashboard['rows'][0]
         else:
